# Simple Diceware

Create diceware-style passwords from the command line. 

Wordlist copied from https://www.eff.org/files/2016/07/18/eff_large_wordlist.txt

### Install

`pip install --user simple-diceware`

### Use

`diceware 6` to generate six-word passphrase
